==> distribution-5.50.0.zip: drr/regulation/jfsa/rewrite/trade/validation/JFSANonReportableValidator.java <==
package drr.regulation.jfsa.rewrite.trade.validation;

import com.google.common.collect.Lists;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.Validator;
import drr.enrichment.common.EnrichmentData;
import drr.regulation.jfsa.rewrite.trade.JFSANonReportable;
import java.util.List;

import static com.google.common.base.Strings.isNullOrEmpty;
import static com.rosetta.model.lib.expression.ExpressionOperators.checkCardinality;
import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;
import static java.util.stream.Collectors.toList;

public class JFSANonReportableValidator implements Validator<JFSANonReportable> {

	private List<ComparisonResult> getComparisonResults(JFSANonReportable o) {
		return Lists.<ComparisonResult>newArrayList(
				checkCardinality("enrichment", (EnrichmentData) o.getEnrichment() != null ? 1 : 0, 0, 1)
			);
	}

	@Override
	public List<ValidationResult<?>> getValidationResults(RosettaPath path, JFSANonReportable o) {
		return getComparisonResults(o)
			.stream()
			.map(res -> {
				if (!isNullOrEmpty(res.getError())) {
					return failure("JFSANonReportable", ValidationResult.ValidationType.CARDINALITY, "JFSANonReportable", path, "", res.getError());
				}
				return success("JFSANonReportable", ValidationResult.ValidationType.CARDINALITY, "JFSANonReportable", path, "");
			})
			.collect(toList());
	}

}

==> distribution-5.55.0.zip: drr/regulation/jfsa/rewrite/trade/validation/JFSANonReportableValidator.java <==
package drr.regulation.jfsa.rewrite.trade.validation;

import com.google.common.collect.Lists;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.Validator;
import drr.enrichment.common.EnrichmentData;
import drr.regulation.jfsa.rewrite.trade.JFSANonReportable;
import java.util.List;

import static com.google.common.base.Strings.isNullOrEmpty;
import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.checkCardinality;
import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;
import static java.util.stream.Collectors.toList;

public class JFSANonReportableValidator implements Validator<JFSANonReportable> {

	private List<ComparisonResult> getComparisonResults(JFSANonReportable o) {
		return Lists.<ComparisonResult>newArrayList(
				checkCardinality("enrichment", (EnrichmentData) o.getEnrichment() != null ? 1 : 0, 0, 1)
			);
	}

	@Override
	public List<ValidationResult<?>> getValidationResults(RosettaPath path, JFSANonReportable o) {
		return getComparisonResults(o)
			.stream()
			.map(res -> {
				if (!isNullOrEmpty(res.getError())) {
					return failure("JFSANonReportable", ValidationResult.ValidationType.CARDINALITY, "JFSANonReportable", path, "", res.getError());
				}
				return success("JFSANonReportable", ValidationResult.ValidationType.CARDINALITY, "JFSANonReportable", path, "");
			})
			.collect(toList());
	}

}
